@@ -1,5 +1,8 @@
 scene3d <- function() {
   
+  saveSubscene <- currentSubscene3d()
+  on.exit(useSubscene3d(saveSubscene))
+  
   defaultmaterial <- material3d()
   
   matdiff <- function(mat) {
@@ -24,8 +27,12 @@ scene3d <- function() {
       if (rgl.attrib.count(id, a))
         result[[a]] <- rgl.attrib(id, a)
     flags <- rgl.attrib(id, "flags")
-    if (length(flags) && "ignoreExtent" %in% rownames(flags)) 
-      result$ignoreExtent <- flags["ignoreExtent", 1]
+    if (length(flags)) {
+    	if ("ignoreExtent" %in% rownames(flags)) 
+          result$ignoreExtent <- flags["ignoreExtent", 1]
+    	if ("fixedSize" %in% rownames(flags))
+    	  result$fixedSize <- flags["fixedSize", 1]
+    }
     if (!is.null(result$ids)) {
       objlist <- vector("list", nrow(result$ids))
       for (i in seq_len(nrow(result$ids)))
@@ -186,7 +193,7 @@ plot3d.rglscene <- function(x, add=FALSE, ...) {
   } else 
     results <- plot3d(root, x$objects, root = TRUE, ...)
   
-  invisible(results)
+  highlevel(results)
 }   
 
 plot3d.rglsubscene <- function(x, objects, root = TRUE, ...) {
@@ -239,8 +246,6 @@ plot3d.rglsubscene <- function(x, objects, root = TRUE, ...) {
   } else
     return(list(results=results, objects=objects))
 }
-       
-  
 
 plot3d.rglobject <- function(x, ...) {
   type <- x$type
