@@ -22,5 +22,5 @@ open3d()
 material3d(texture = system.file("textures","rgl2.png", package="rgl"))
 spin <- spin3d(rpm=6,axis=c(0,0,1))
 if (!rgl.useNULL())
-  play3d(wave, 10)
+  play3d(wave, 10, startTime = 5)
 
