@@ -3,9 +3,10 @@ source("setup.R")
 knitr::opts_chunk$set(rgl.newwindow = TRUE)
 set.seed(123)
 
-## ----plot3d, webgl=TRUE--------------------------------------------------
+## ----echo=1--------------------------------------------------------------
 with(iris, plot3d(Sepal.Length, Sepal.Width, Petal.Length, 
                   type="s", col=as.numeric(Species)))
+rglwidget()
 
 ## ----persp3d, webgl=TRUE, fig.height=3, fig.width=6----------------------
 library(MASS)
@@ -57,6 +58,18 @@ shade3d(oh3d(col=cols[7]))
 ## ------------------------------------------------------------------------
 par3d("mouseMode")
 
+## ----echo = 2:3----------------------------------------------------------
+rgl.close()
+persp3d(volcano, col = "green")
+rglwidget()
+
+## ------------------------------------------------------------------------
+lattice::wireframe(volcano, col = "green", 
+		   screen = rglToLattice())
+angles <- rglToBase()
+persp(volcano, col = "green", shade = TRUE,
+      theta = angles$theta, phi = angles$phi)
+
 ## ----echo=FALSE----------------------------------------------------------
 setdiff(ls("package:rgl"), documentedfns)
 
