@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: rglmath.h 1113 2014-07-16 13:03:01Z murdoch $
+// $Id: rglmath.h 1137 2014-09-24 19:03:24Z murdoch $
 
 #include <cmath>
 #include <cfloat>
@@ -157,7 +157,12 @@ public:
   void setIdentity(void);
   void setRotate(const int axis, const float degree);
   void getData(double* dest);
+  void loadData(const double* from);
+  void loadData(const float* from);
+  void loadData(const Matrix4x4& from);
   void transpose();
+  static Matrix4x4 scaleMatrix(double sx, double sy, double sz); 
+  static Matrix4x4 translationMatrix(double x, double y, double z);
 private:
   inline float  val(int row, int column) const { return data[4*column+row]; }
   inline float& ref(int row, int column) { return data[4*column+row]; }
